# NOTE

# TODO
- removes deprecated things in option.py
- apply generic typing in option.py
- more accurate error messages in option.py
- resolve default value problem in option.py
- Add Docs to explain how the None value works in option.py:Option:\_\_set__
- refactor Option to abstraction by different types.
# DOING

# TEST / DISCUSS

# DONE